pub(super) static ATTR_PAYABLE: &str = "payable";
pub(super) static ATTR_OUTPUT_NAME: &str = "output_name";
pub(super) static ATTR_PAYMENT: &str = "payment"; // synonymous with `payment_amount`
pub(super) static ATTR_PAYMENT_AMOUNT: &str = "payment_amount";
pub(super) static ATTR_PAYMENT_TOKEN: &str = "payment_token";
pub(super) static ATTR_PAYMENT_NONCE: &str = "payment_nonce";
pub(super) static ATTR_VAR_ARGS: &str = "var_args";
pub(super) static ATTR_INIT: &str = "init";
pub(super) static ATTR_VIEW: &str = "view";
pub(super) static ATTR_LEGACY_EVENT: &str = "legacy_event";
pub(super) static ATTR_EVENT: &str = "event";
pub(super) static ATTR_EVENT_INDEXED: &str = "indexed";
pub(super) static ATTR_ENDPOINT: &str = "endpoint";
pub(super) static ATTR_CALLBACK_DECL: &str = "callback";
pub(super) static ATTR_CALLBACK_RAW_DECL: &str = "callback_raw";
pub(super) static ATTR_CALLBACK_CALL_RESULT: &str = "call_result";
pub(super) static ATTR_STORAGE_GET: &str = "storage_get";
pub(super) static ATTR_STORAGE_SET: &str = "storage_set";
pub(super) static ATTR_STORAGE_MAPPER: &str = "storage_mapper";
pub(super) static ATTR_STORAGE_IS_EMPTY: &str = "storage_is_empty";
pub(super) static ATTR_STORAGE_CLEAR: &str = "storage_clear";
pub(super) static ATTR_PROXY: &str = "proxy";
